# Generate devel rpm
%global with_devel 0
# Build with debug info rpm
%global with_debug 0
# Run unit tests
%global with_tests 0
# Build test binaries
%global with_test_binaries 0

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global git_commit 2f81a73f5859ff5369135d2715d6bb08e607ded8
%global git_shortcommit  %(c=%{git_commit}; echo ${c:0:7})

%global provider        github
%global provider_tld    com
%global project         maistra
%global repo            istio-operator

# are we building community or product rpms
%global community_build  false

# https://github.com/maistra/istio-operator
%global provider_prefix %{provider}.%{provider_tld}/%{project}

# Use /usr/local as base dir, once upstream heavily depends on that
%global _prefix /usr/local

Name:           servicemesh-operator
Version:        1.1.15
Release:        1%{?dist}
Summary:        A Kubernetes operator to manage Istio.
License:        ASL 2.0
URL:            https://%{provider_prefix}/%{repo}

Source0:        https://%{provider_prefix}/%{repo}/archive/%{git_commit}/%{repo}-%{git_commit}.tar.gz
Patch0:         0001-MAISTRA-1464-Update-gopkg.in-yaml.v2-to-v2.3.0.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  x86_64 ppc64le s390x
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  golang >= 1.9

%description
Istio-operator is a kubernetes operator to manage the lifecycle of Istio.

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch: x86_64 ppc64le s390x

%description devel
Istio-operator is a kubernetes operator to manage the lifecycle of Istio.
%endif

%prep

rm -rf OPERATOR

mkdir -p OPERATOR/src/github.com/maistra/istio-operator
tar zxf %{SOURCE0} -C OPERATOR/src/github.com/maistra/istio-operator --strip=1

pushd OPERATOR/src/github.com/maistra/istio-operator
%patch0 -p1
popd

%build
cd OPERATOR
export GOPATH=$(pwd):%{gopath}
pushd src/github.com/maistra/istio-operator/
COMMUNITY=%{community_build} GO111MODULE=on VERSION=%{version}-%{release} GITREVISION=%{git_shortcommit} GITSTATUS=Clean GITTAG=%{version} GIT_UPSTREAM_REMOTE="_DUMMY_" OFFLINE_BUILD="true" make compile collect-resources
popd

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir}
pushd OPERATOR/src/github.com/maistra/istio-operator/tmp/_output/bin/

%if 0%{?with_debug}
    cp -pav istio-operator $RPM_BUILD_ROOT%{_bindir}/
%else
    mkdir stripped

    echo "Dumping dynamic symbols"
        nm -D istio-operator --format=posix --defined-only \
  | awk '{ print $1 }' | sort > dynsyms

       echo "Dumping function symbols"
       nm istio-operator --format=posix --defined-only \
  | awk '{ if ($2 == "T" || $2 == "t" || $2 == "D") print $1 }' \
  | sort > funcsyms

        echo "Grabbing other function symbols"
        comm -13 dynsyms funcsyms > keep_symbols


  COMPRESSED_NAME="operator_debuginfo"
        echo "remove unnecessary debug info"
        objcopy -S --remove-section .gdb_index --remove-section .comment \
  --keep-symbols=keep_symbols "istio-operator" "${COMPRESSED_NAME}"

        echo "stripping operator"
        strip -o "stripped/istio-operator" -s istio-operator


        echo "compress debugdata for istio-operator into ${COMPRESSED_NAME}.xz"
        xz "${COMPRESSED_NAME}"

        echo "inject compressed data into .gnu_debugdata for istio-operator"
        objcopy --add-section ".gnu_debugdata=${COMPRESSED_NAME}.xz" "stripped/istio-operator"

        cp -pav "stripped/istio-operator" "${RPM_BUILD_ROOT}%{_bindir}/"
%endif
popd

mkdir -p $RPM_BUILD_ROOT%{_datadir}/istio-operator/helm
TEMPLATES_DIR=$RPM_BUILD_ROOT/%{_datadir}/istio-operator/default-templates
mkdir -p ${TEMPLATES_DIR}

pushd OPERATOR/src/github.com/maistra/istio-operator/tmp/_output/resources
# install the charts
cp -rpavT helm/ $RPM_BUILD_ROOT%{_datadir}/istio-operator/helm
# install the templates
cp -rpavT default-templates/ $RPM_BUILD_ROOT%{_datadir}/istio-operator/default-templates

#install manifests
cp -rpavT manifests/ $RPM_BUILD_ROOT/manifests
popd

%files
%{_bindir}/istio-operator
%{_datadir}/istio-operator
/manifests

%changelog
* Sat May 15 2021 Product Release - 1.1.15-1
- Update to latest release

* Fri May 07 2021 Product Release - 1.1.14-2
- Update to latest release

* Fri May 07 2021 Product Release - 1.1.14-1
- Update to latest release

* Sun Apr 11 2021 Product Release - 1.1.13-1
- Update to latest release

* Tue Jan 26 2021 Product Release - 1.1.12-3
- Update to latest release

* Tue Jan 19 2021 Product Release - 1.1.12-2
- Update to latest release

* Mon Jan 18 2021 Product Release - 1.1.12-1
- Update to latest release

* Tue Dec 15 2020 Product Release - 1.1.11-3
- Update to latest release

* Mon Dec 14 2020 Product Release - 1.1.11-2
- Update to latest release

* Mon Dec 14 2020 Product Release - 1.1.11-1
- Update to latest release

* Sat Oct 10 2020 Product Release - 1.1.10-1
- Update to latest release

* Thu Sep 24 2020 Product Release - 1.1.9-1
- Update to latest release

* Thu Sep 17 2020 Product Release - 1.1.8-4
- Update to latest release

* Fri Sep 11 2020 Product Release - 1.1.8-3
- Update to latest release

* Fri Sep 11 2020 Product Release - 1.1.8-2
- Update to latest release

* Mon Aug 10 2020 Product Release - 1.1.7-2
- Update to latest release

* Sat Aug 08 2020 Product Release - 1.1.7-1
- Update to latest release

* Mon Aug 03 2020 Product Release - 1.1.6-1
- Update to latest release

* Sun Jul 26 2020 Product Release - 1.1.5-3
- Update to latest release

* Mon Jul 20 2020 Product Release - 1.1.5-2
- Update to latest release

* Fri Jul 17 2020 Product Release - 1.1.5-1
- Update to latest release

* Thu Jul 02 2020 Product Release - 1.1.4-4
- Update to latest release

* Fri Jun 26 2020 Product Release - 1.1.4-3
- Update to latest release

* Fri Jun 26 2020 Product Release - 1.1.4-2
- Update to latest release

* Wed Jun 24 2020 Product Release - 1.1.4-1
- Update to latest release

* Mon Jun 15 2020 Product Release - 1.1.3-4
- Update to latest release

* Mon Jun 15 2020 Product Release - 1.1.3-3
- Update to latest release

* Wed Jun 03 2020 Product Release - 1.1.3-2
- Update to latest release

* Tue May 26 2020 Product Release - 1.1.3-1
- Update to latest release

* Tue May 26 2020 Product Release - 1.1.2-3
- Update to latest release

* Mon May 11 2020 Product Release - 1.1.2-2
- Update to latest release

* Mon May 11 2020 Product Release - 1.1.1-1
- Update to latest release

* Tue Apr 28 2020 Product Release - 1.1.1-5
- Update to latest release

* Mon Apr 27 2020 Product Release - 1.1.1-4
- Update to latest release

* Fri Apr 24 2020 Product Release - 1.1.1-3
- Update to latest release

* Wed Apr 22 2020 Product Release - 1.1.1-2
- Update to latest release

* Thu Apr 09 2020 Product Release - 1.1.0-12
- Update to latest release

* Thu Apr 09 2020 Product Release - 1.1.0-11
- Update to latest release

* Thu Apr 09 2020 Product Release - 1.1.0-10
- Update to latest release

* Fri Apr 03 2020 Product Release - 1.1.0-9
- Update to latest release

* Thu Apr 02 2020 Product Release - 1.1.0-8
- Update to latest release

* Wed Apr 01 2020 Product Release - 1.1.0-7
- Update to latest release

* Wed Apr 01 2020 Product Release - 1.1.0-6
- Update to latest release

* Wed Apr 01 2020 Product Release - 1.1.0-5
- Update to latest release

* Tue Mar 31 2020 Product Release - 1.1.0-4
- Update to latest release

* Tue Mar 31 2020 Product Release - 1.1.0-3
- Update to latest release

* Wed Feb 26 2020 Brian Avery - 1.1.0-2
- Update for 1.1.0

* Thu Jan 16 2020 Product Release - 1.1.0-1
- Update to 1.1.0 release

* Tue Aug 27 2019 Product Release - 1.0.0-14
- Update to latest release

* Sat Aug 24 2019 Product Release - 1.0.0-14
- Update to latest release

* Fri Aug 23 2019 Product Release - 1.0.0-13
- Update to latest release

* Fri Aug 23 2019 Product Release - 1.0.0-12
- Update to latest release

* Fri Aug 16 2019 Product Release - 1.0.0-11
- Update to latest release

* Fri Aug 16 2019 Product Release - 1.0.0-3
- Update to latest release

* Fri Aug 16 2019 Product Release - 1.0.0-2
- Update to latest release

* Fri Aug 16 2019 Product Release - 1.0.0-1
- Update to latest release

* Fri Aug 16 2019 Product Release - 1.0.0-10
- Update to latest release

* Fri Aug 16 2019 Product Release - 1.0.0-9
- Update to latest release

* Thu Aug 15 2019 Product Release - 1.0.0-8
- Update to latest release

* Thu Aug 15 2019 Product Release - 1.0.0-7
- Update to latest release

* Thu Aug 15 2019 Product Release - 1.0.0-6
- Update to latest release

* Tue Aug 13 2019 Jonh Wendell <jonh.wendell@redhat.com> - 1.0.0-5
- Use /usr/local/share/istio-operator as the resources dir

* Thu Aug 08 2019 Daniel Grimm <dgrimm@redhat.com> - 1.0.0-4
- Added templates directory
- pulled in latest operator changes
- pulled in latest Maistra charts

* Tue Aug 6 2019 Brian Avery - 1.0.0-3
- Fixed manifest dir location

* Sun Aug 4 2019 Brian Avery - 1.0.0-2
- Added manifests for operator
* Mon Jul 22 2019 Release - 1.0.0-1
- Update to Istio 1.1.11

* Thu Jul 11 2019 Daily Build - 0.12.0-7
- Update to latest release

* Wed Jul 10 2019 Daily Build - 0.12.0-6
- Update to latest release

* Tue Jul 09 2019 Daily Build - 0.12.0-5
- Update to latest release

* Tue Jul 09 2019 Daily Build - 0.12.0-4
- Update to latest release

* Tue Jul 09 2019 Daily Build - 0.12.0-3
- Update to latest release

* Wed Jun 12 2019 Brian Avery <bavery@redhat.com> - 0.12.0-2
- Updated to Istio 1.1.8

* Tue Jun 11 2019 Brian Avery <bavery@redhat.com> - 0.12.0-1
- Hide prometheus traffic in Kiali, improve diff, and fix permissions

* Tue Jun 11 2019 Brian Avery <bavery@redhat.com> - 0.11.1-11
- Rebuilding 0.11

* Mon Jun 10 2019 Brian Avery <bavery@redhat.com> - 0.11.1-10
- Rebuilding 0.11

* Fri Jun  7 2019 Brian Avery <bavery@redhat.com> - 0.11.1-9
- Add registry.redhat.io to hub

* Wed May 29 2019 Kevin Conner <kconner@redhat.com> - 0.11.0-8
- Pull in latest operator changes

* Tue May 28 2019 Kevin Conner <kconner@redhat.com> - 0.11.0-7
- Pull in latest operator changes

* Fri May 24 2019 Brian Avery <bavery@redhat.com> - 0.11.0-6
- Enqueue ServiceMeshMemberRoll controller requests on namespace events

* Thu May 23 2019 Kevin Conner <kconner@redhat.com> - 0.11.0-5
- Pull in latest operator changes

* Wed May 22 2019 Brian Avery <bavery@redhat.com> - 0.11.0-3
- Move Jaeger earlier in the installation process

* Tue May 21 2019 Brian Avery <bavery@redhat.com> - 0.11.0-2
- updated Kiali version

* Mon May 20 2019 Brian Avery <bavery@redhat.com> - 0.11.0-1
- stripping RPM

* Mon May 20 2019 Brian Avery <bavery@redhat.com> - 0.11.0-1
- maistra 0.11

* Mon Apr 15 2019 Rob Cernich <rcernich@redhat.com> - 0.10.0-6
- watch istio-system for ControlPlane CR
- watch istio-operator for Installation CR

* Thu Mar 28 2019 Rob Cernich <rcernich@redhat.com> - 0.10.0-5
- Updates for sidecar injector
- Bump 3scale version to 0.5.0

* Thu Mar 28 2019 Rob Cernich <rcernich@redhat.com> - 0.10.0-4

* Thu Mar 28 2019 Rob Cernich <rcernich@redhat.com> - 0.10.0-3

* Thu Mar 28 2019 Rob Cernich <rcernich@redhat.com> - 0.10.0-2

* Thu Mar 28 2019 Rob Cernich <rcernich@redhat.com> - 0.10.0-1
- Added helm charts used by new installer

* Mon Mar 25 2019 Brian Avery <bavery@redhat.com> - 0.10.0-1
- Updated to 0.10.0/New installer

* Mon Mar 4 2019 Kevin Conner <kconner@redhat.com> - 0.9.0-1
- Updated to 0.9.0

* Thu Feb 14 2019 Kevin Conner <kconner@redhat.com> - 0.8.0-1
- Updated to 0.8.0

* Mon Jan 28 2019 Kevin Conner <kconner@redhat.com> - 0.7.0-3
- Updates to 3scale adapter integration

* Fri Jan 25 2019 Kevin Conner <kconner@redhat.com> - 0.7.0-2
- Updated to include 3scale adapter configuration

* Sun Jan 20 2019 Kevin Conner <kconner@redhat.com> - 0.7.0
- Updated to 0.7.0

* Thu Jan 3 2019 Kevin Conner <kconner@redhat.com> - 0.6.0-2
- Fixed up repo name and source file

* Mon Dec 31 2018 Kevin Conner <kconner@redhat.com> - 0.6.0
- Updated to 0.6.0

* Fri Nov 23 2018 Kevin Conner <kconner@redhat.com> - 0.5.0
- Updated to 0.5.0

* Wed Oct 31 2018 Kevin Conner <kconner@redhat.com> - 0.4.0
- Updated to 0.4.0

* Wed Oct 17 2018 Kevin Conner <kconner@redhat.com> - 0.3.0
- Updated tothe real 0.3.0

* Fri Oct 12 2018 Brian Avery <bavery@redhat.com> 0.3.0
- Maistra 0.3.0 release

* Thu Sep 27 2018 Kevin Conner <kconner@redhat.com> - 0.2.0
- Update to latest maistra 0.2.0 source

* Tue Sep 4 2018 Brian Avery <brian.avery@redhat.com> - 0.1.0
- Stripped binaries

* Tue Aug 14 2018 Brian Avery <brian.avery@redhat.com> - 0.1.0
- First package
